InferUserAgent

Enum InferUserAgent 

pub enum InferUserAgent {
    Auto,
    Never,
}
Settings controlling how the user agent should be inferred.

Specifically frontend SDKs may want to have the user agent and browser information automatically inferred from the HTTP header provided user agent.

Variants



Auto

The user agent should be inferred from the http request submitting the spans.



Never

The user agent should never be inferred.

Implementations

Source

impl InferUserAgent

pub fn is_auto(&self) -> bool

Returns true if self is Self::Auto.