pub struct ContainerMetadata {
pub version: Option<u16>,
pub ingest_settings: Option<IngestSettings>,
}Expand description
Metadata supplied with an item container containing spans.
See also: https://develop.sentry.dev/sdk/telemetry/spans/span-protocol/#version-and-ingest_settings-properties.
Versions
Behaviour
Different versions influence how spans are normalized and processed:
| Version | client ip | user agent |
|---|---|---|
| none | {{auto}} | never |
| 2 | {{auto}}, settings | settings |
For example in version 2, the client ip is inferred if either the client address attribute is
set to auto or the ingest settings specify infer_ip to auto.
The user agent is only considered if ingest settings specify infer_user_agent as auto.
Schema Changelog
| Version | Changes |
|---|---|
| 2 | Adds ingest_settings |
Fields
version: Option<u16>The metadata version
The version influences how spans are processed during ingestion.
ingest_settings: Option<IngestSettings>Settings controlling parts of the ingestion of individual spans.
Supported since version 2.