pub struct ContainerMetadata {
pub version: Option<u16>,
pub ingest_settings: Option<IngestSettings>,
}Expand description
Metadata supplied with an item container containing spans.
See also: https://develop.sentry.dev/sdk/telemetry/spans/span-protocol/#version-and-ingest_settings-properties.
Fields
version: Option<u16>The metadata version
The version influences how spans are processed during ingestion.
Currently supported versions:
missing: no behaviour change2: adds support foringest_settings
ingest_settings: Option<IngestSettings>Settings controlling parts of the ingestion of individual spans.
Supported since version 2.